@@ -1,7 +1,8 @@
 #![forbid(unsafe_code)]
 #![deny(
+    clippy::dbg_macro,
     missing_copy_implementations,
-    missing_crate_level_docs,
+    rustdoc::missing_crate_level_docs,
     missing_debug_implementations,
     missing_docs,
     nonstandard_style,
@@ -38,7 +39,7 @@ assert_ok!(
 );
 
 assert_ok!(
-    get("/").with_request_header(("cookie", "some_cookie=trillium")).on(&handler),
+    get("/").with_request_header("cookie", "some_cookie=trillium").on(&handler),
     "current cookie value: trillium",
     "set-cookie" => "some_cookie=some-cookie-value; Path=/"
 );
